% This is example code can be used to estmate False Positive Rates from
% N-hacking as a function of parameters, as described in: 
% Reinagel, P "Is N-Hacking Ever OK?" bioRxiv 2019
%
% Anyone may copy and modify this code, but please keep this attribution in
% the code, and please cite the paper above if you use the code.
% written in Matlab 2018a 
% Pamela Reinagel,  2019  UCSD

clear, close all, clc
%cd('?');% whatever your working directory is (files will be saved here)

M=10^6; %Number of experiments to simulate in each condition
policies={'Asymmetric','Symmetric'};%the two policies discussed in paper
alphavals=[.01 .05];%[.005 .01 .025 .05];
%Note that w=0 in either policy = the standard fixed-N policy
wvals=[.4];% up to 0.4 the relation of w to k is ~linear even for large Ninit
NinitVals= 2.^[1:6];%values of Ninit to try, NB the minimum Ninit=2
NincrVals= 2.^[0:6];%values of Nincr to try
Rpt=1;%Number of times to repeat the entire simulation.

%Note: my plotting code assumes that no dimensions of these matrices are
%singleton, so this code enforces that each dimension is at least 2 even if
%not needed.
a=max([length(policies) 2]);
b=max([length(NinitVals) 2]);
c=max([length(NincrVals) 2]);
d=max([length(wvals) 2]);
e=max([length(alphavals) 2]);
f=max([Rpt 2]);
%matrix to save the FP rate for every condition 
FPrate=nan(a,b,c,d,e,f);
%matrix to document the avg sample number required on ea condition
AvgNused=nan(a,b,c,d,e,f);
%matrix to document the fraction of experiments terminated by the cap
SampleCapReached=nan(a,b,c,d,e,f);
clear a b c d e f
clc
for policy=1:2
    for rptNo=1:Rpt,
        for Ninit_ind=1:length(NinitVals),
            Ninit=NinitVals(Ninit_ind);
            Nmax=3*Ninit; % maximum N to sample before quitting 
            % alternatively you could set a global Nmax at the top, in 
            % which case it should be Nmax >= 2*max(NinitVals)

            maxinc=max(find(NincrVals<=Ninit));%optional restriction, just makes sense to me
            for Nincr_ind=1:maxinc,
                Nincr=NincrVals(Nincr_ind);
                fprintf('\nPolicy %s repeat %d N=%d increment=%d %s w=...',...
                    policies{policy}, rptNo,Ninit,Nincr, datestr(now));
                for w_ind=1:length(wvals),
                    w=wvals(w_ind);
                    fprintf('%.1f, ',w);
                    for alpha_ind=1:length(alphavals),
                        alpha=alphavals(alpha_ind);
                        [FPrate(policy,Ninit_ind,Nincr_ind,w_ind,alpha_ind,rptNo) ...
                            AvgNused(policy,Ninit_ind,Nincr_ind,w_ind,alpha_ind,rptNo) ...
                            SampleCapReached(policy,Ninit_ind,Nincr_ind,w_ind,alpha_ind,rptNo)]=...
                        simulateExperiments(policies{policy},M,alpha,w,Ninit,Nincr,Nmax);
                    end %vary alpha
                end%vary w 
                save WorkingVariables.mat
            end%vary Nincr
        end %vary Ninit
    end %repeat calculations
end%vary policy
 
%NOTE: This script saves the working variables periodically so you can open
%a second matlab window to run the plotting code on intermediate results:
plotFPresults('WorkingVariables.mat')
 