function plotFPresults(filename,egW,egAlpha)
%plotFPresults(filename)
% filename is a full path to a file containing the variables saved from
% the workspace of example script 1, amd makes plot (cf Fig 2 A,B,D,E)
% file must contain at least
% FPrate (indexed by policy, Nint, Ninc, w, alpha, rpt) w/no singleton dims.
% and vectors: policies,NinitVals,NincrVals,wvals, alphavals
%
% optional arguments egW and egAlpha define the choice of w and alpha
% to show in the leftmost plots; otherwise value from file or default is chosen
 
X=load(filename);
%check for optional arguments and set as required
if exist('egW','var') & ~isempty(egW) ...%if a value was passed in
        & ~ ismember(egW,X.wvals),%but it was not valid
    fprintf('condition w=%.3f was not simulated. Choosing another egW\n',egW);
    clear egW
end
if ~exist('egW','var') | isempty(egW),%if not passed in, set egW
    if  isfield(X,'egW') & ~isempty(X.egW),%check if in file
        egW=X.egW;
    else %choose largest w up to 1, or lowest if all >1
        tmp=sort(X.wvals); ind=max(find(tmp<=1));
        if ~isempty(ind), egW=tmp(ind); else egW=min(X.wvals); end
    end
    %echo the selected value to console
    fprintf('Panels A,D show results from w=%.3f\n',egW);
end
if exist('egAlpha','var') & ~isempty(egAlpha) ...%if a value was passed in
        & ~ ismember(egAlpha,X.alphavals),%but it was not valid
    fprintf('condition alpha=%.3f was not simulated. Choosing another egAlpha\n',egAlpha);
    clear egAlpha
end
if ~exist('egAlpha','var') | isempty(egAlpha),%if not passed in, set
    if isfield(X,'egAlpha') & ~isempty(X.egAlpha),
        egAlpha=X.egAlpha;
    else %choose largest alpha up to .05, or the lowest if all >.05
        tmp=sort(X.alphavals); ind=max(find(tmp<=.05));
        if ~isempty(ind), egAlpha=tmp(ind); else egAlpha=min(X.alphavals); end
    end
    %echo the selected value to console
    fprintf('Panels A,D show results from alpha=%.3f\n',egAlpha);
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
colors=jet(length(X.NincrVals));
symb='osv^dv<>ph+x*';%distinguishes alpha values
for policy=1:2,
    offset=2*(policy-1);%subpplot indexing
 
    %in the first panel show raw FP for some choice of alpha and w
    subplot(2,2,offset+1),hold off
    alphaind=find(X.alphavals==egAlpha);
    wind=find(X.wvals==egW);
    %avg over repeats
    for inc=1:length(X.NincrVals),%Nincrement tested
        tmpFP=squeeze(X.FPrate(policy,:,inc,wind,alphaind,:));
        plot(log2(X.NinitVals),nanmean(tmpFP'),'o-','color',colors(inc,:),...
            'markerfacecolor',colors(inc,:)); hold on
    end
    ylabel('FP Rate'), xlabel('log2(N_{init})')
    set(gca,'fontsize',12,'box','off');
    set(gca, 'xlim',[0 8],'xtick',[1:7]);
    plot([0 8],egAlpha*[1 1],'k-')
    if policy==1,
        legend(num2str(X.NincrVals(1:inc)'),'location','southeast');
    end
    
    %in the second panel scale to alpha and w and show all
    %average over repeats if repeats are available
    subplot(2,2,offset+2),hold off
    for w_ind=1:length(X.wvals),
        w=X.wvals(w_ind);%choose some example
        for alpha_ind=1:length(X.alphavals),
            alpha=X.alphavals(alpha_ind);
            for inc=1:length(X.NincrVals),
                %compute (FP/alpha-1)/w
                Yval= (nanmean( squeeze(X.FPrate(policy,:,inc,w_ind,alpha_ind,:))')/alpha-1)/w;
                Xval=log2(X.NinitVals)-0.125+0.05*w_ind;%slightly offset ws
                plot(Xval,Yval,symb(alpha_ind),'color',colors(inc,:),...
                    'markersize',4);hold on
            end
        end
    end
    set(gca,'ylim',[-1 1],'xlim', [0 8],'xtick',[1:7],'box','off','fontsize',12)
    plot(get(gca,'xlim'),[0 0],'k-');
    ylabel('(FP/\alpha - 1)/w'), xlabel('log2(N_{init})')
    
    %add rule of thumb lines
    if policy==1,thumb=[0.25 0.5];else thumb=[-.25 -.5];end
    for k=1:2,plot([0 8],thumb(k)*[1 1],'k:');end
end

labels='abcd';
for sp=1:4,
    subplot(2,2,sp),hold on
    xl=get(gca,'xlim');yl=get(gca,'ylim');
    xpos=min(xl)-0.2*range(xl);
    ypos=max(yl)+0.1*range(yl);
    text(xpos,ypos,labels(sp),'fontsize',36);
end
